@@ -8,6 +8,7 @@ from jupyter_process_manager.class_processes_manager import \
     JupyterProcessesManager
 from . import logger
 from .function_wrapper import clear_output
+from .function_wrapper import read_stdout
 
 
 JupyterProcessManager = JupyterProcessesManager
@@ -15,7 +16,9 @@ JPM = JupyterProcessesManager
 
 
 __all__ = [
-    "JupyterProcessesManager", "JupyterProcessManager", "JPM", "clear_output"]
+    "JupyterProcessesManager", "JupyterProcessManager", "JPM",
+    "clear_output", "read_stdout",
+]
 
 # Create LOGGER for current project
 logger.initialize_project_logger(
